pub trait OpaqueProject<Target> {
type Output;
// Required method
fn project(self) -> Self::Output;
}Expand description
Projects an opaque wrapper receiver into the corresponding inner receiver.
Generated forwarding impls use this trait instead of hard-coding whether a
receiver should call as_inner, as_inner_mut, or into_inner.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".